==> foundation-0.0.45.tgz: package/Default/Tools/Brush/AdvancedBrushTool.js <==
//util
//tools
import { BrushTool } from "./Brush.js";
import { TaskTool } from "../Tasks/TasksTool.js";
const tasks = new TaskTool();
export class AdvancedBrush extends BrushTool {
    mode = "async";
    setMode(mode) {
        this.mode = mode;
        return this;
    }
    paintAndAwaitUpdate() {
        const self = this;
        return new Promise((resolve) => {
            self.paintAndUpdate(() => {
                resolve(true);
            });
        });
    }
    eraseAndAwaitUpdate() {
        const self = this;
        return new Promise((resolve) => {
            self.eraseAndUpdate(() => {
                resolve(true);
            });
        });
    }
    paintAndUpdate(onDone) {
        tasks.setFocalPoint(this.location);
        tasks.voxelUpdate.paint.run(this.location, this.getRaw(), () => {
            if (onDone)
                onDone();
        }, this.mode);
    }
    eraseAndUpdate(onDone) {
        tasks.setFocalPoint(this.location);
        tasks.voxelUpdate.erase.run(this.location, () => {
            if (onDone)
                onDone();
        }, this.mode);
    }
    update(onDone) {
        tasks.setFocalPoint(this.location);
        tasks.voxelUpdate.update.run(this.location, this.getRaw(), () => {
            if (onDone)
                onDone();
        }, this.mode);
    }
    updateAndAwait() {
        return new Promise((resolve) => {
            this.update(() => {
                resolve(true);
            });
        });
    }
    explode(radius = 6, onDone) {
        tasks.setFocalPoint(this.location);
        tasks.explosion.run(this.location, radius, () => {
            if (onDone)
                onDone();
        });
    }
    explodeAwaitUpdate(radius = 6) {
        return new Promise((resolve) => {
            this.explode(radius, () => {
                resolve(true);
            });
        });
    }
}

==> foundation-0.0.52.tgz: package/Default/Tools/Brush/AdvancedBrushTool.js <==
//util
//tools
import { BrushTool } from "./Brush.js";
import { TaskTool } from "../Tasks/TasksTool.js";
const tasks = new TaskTool();
export class AdvancedBrush extends BrushTool {
    mode = "async";
    setMode(mode) {
        this.mode = mode;
        return this;
    }
    paintAndAwaitUpdate() {
        return new Promise((resolve) => {
            this.paintAndUpdate(() => {
                resolve(true);
            });
        });
    }
    eraseAndAwaitUpdate() {
        const self = this;
        return new Promise((resolve) => {
            self.eraseAndUpdate(() => {
                resolve(true);
            });
        });
    }
    paintAndUpdate(onDone) {
        tasks.setFocalPoint(this.location);
        console.log("run voxel updte", this.getRaw());
        tasks.voxelUpdate.paint.run(this.location, this.getRaw(), () => {
            console.log("DONE", this.getRaw());
            if (onDone)
                onDone();
        }, this.mode);
    }
    eraseAndUpdate(onDone) {
        tasks.setFocalPoint(this.location);
        tasks.voxelUpdate.erase.run(this.location, () => {
            if (onDone)
                onDone();
        }, this.mode);
    }
    update(onDone) {
        tasks.setFocalPoint(this.location);
        tasks.voxelUpdate.update.run(this.location, this.getRaw(), () => {
            if (onDone)
                onDone();
        }, this.mode);
    }
    updateAndAwait() {
        return new Promise((resolve) => {
            this.update(() => {
                resolve(true);
            });
        });
    }
    explode(radius = 6, onDone) {
        tasks.setFocalPoint(this.location);
        tasks.explosion.run(this.location, radius, () => {
            if (onDone)
                onDone();
        });
    }
    explodeAwaitUpdate(radius = 6) {
        return new Promise((resolve) => {
            this.explode(radius, () => {
                resolve(true);
            });
        });
    }
}
